@@ -681,7 +681,7 @@ function s020_magma.Cooldown_Deactivation()
   Scenario.WriteToBlackboard(Scenario.LUAPropIDs.COOLDOWN_FINISHED, "b", true)
   s020_magma.ThermalTrapChange()
   s020_magma.PistonDeactivation()
-  Game.PushSetup("PostCooldown", true, true)
+  -- Game.PushSetup("PostCooldown", true, true)
   Scenario.WriteToBlackboard(Scenario.LUAPropIDs.MAGMA_COOLDOWN_APPLIED, "b", false)
   MAGMA_COOLDOWN_APPLIED = false
 end
@@ -755,6 +755,18 @@ function s020_magma.OnUsableFinishInteract(_ARG_0_)
   end
 end
 
+function s020_magma.OnUsablePrepareUse(actor)
+  Scenario.DisableGlobalTeleport(actor)
+end
+
+function s020_magma.OnUsableCancelUse(actor)
+  Scenario.ResetGlobalTeleport(actor)
+end
+
+function s020_magma.OnUsableUse(actor)
+  Scenario.SetTeleportalUsed(actor)
+end
+
 
 
 
@@ -764,6 +776,25 @@ function s020_magma.SubAreaChangeRequest(_ARG_0_, _ARG_1_, _ARG_2_, _ARG_3_)
 end
 
 
+function s020_magma.SetCooldown(state)
+  Game.SetCooldownFlag(state)
+  if state then
+    Game.PushSetup("Cooldown", true, true)
+  else
+    Game.PopSetup("Cooldown", true, true)
+  end
+end
+
+function s020_magma.OnEnter_TriggerEnableCooldown()
+  if not Init.bEnableExperimentBoss or Scenario.ReadFromPlayerBlackboard("RANDO_DEFEATED_EXPERIMENT", false) then return end
+  s020_magma.SetCooldown(true)
+end
+
+function s020_magma.OnEnter_TriggerDisableCooldown()
+  s020_magma.SetCooldown(false)
+end
+
+
 function s020_magma.OnSubAreaChange(old_subarea, old_actorgroup, new_subarea, new_actorgroup, disable_fade)
     
     
@@ -773,10 +804,19 @@ function s020_magma.OnSubAreaChange(old_subarea, old_actorgroup, new_subarea, ne
   if s020_magma.IsKraidCombatBegin(old_subarea, old_actorgroup, new_subarea, new_actorgroup, disable_fade) then
     s020_magma.Kraid_InitCutscene()
   end
+
+  if old_subarea == "collision_camera_004" and (new_subarea ~= "collision_camera_009" or Game.GetPlayer().vPos[1] < -7000) then
+    s020_magma.SetCooldown(false)
+  end
   if old_subarea == "collision_camera_009" and old_actorgroup == "PostCooldown" then
     Game.PopSetup("Cooldown", true, true)
     Game.PushSetup("PostXRelease", true, true)
-  elseif MAGMA_COOLDOWN_APPLIED == true and old_subarea == "collision_camera_004" and new_subarea == "collision_camera_009" then
+  elseif Init.bEnableExperimentBoss and QUARENTINE_OPENED
+      and new_subarea == "collision_camera_009" and old_subarea == "collision_camera_004"
+      and Game.GetPlayer().vPos[1] > -7000 -- entered through the morph ball launcher
+      and not Scenario.ReadFromPlayerBlackboard("RANDO_DEFEATED_EXPERIMENT", false) then
+    -- begin Experiment fight
+
     local oActor = Game.GetActor("cutsceneplayer_78")
     if oActor ~= nil then
       oActor.CUTSCENE:TryLaunchCutscene()
@@ -825,7 +865,9 @@ function s020_magma.OnCutscene81Ended()
     
     
   s020_magma.Cooldown_Deactivation()
+  Game.PushSetup("PostCooldown", true, true)
   Blackboard.SetProp("s010_cave", "SubareaSetupID[collision_camera_080]", "s", "Default>PostXRelease")
+  Scenario.WriteToPlayerBlackboard("RANDO_DEFEATED_EXPERIMENT", "b", true)
   Game.SetPlayerInteractMovementState()
 end
 
