@@ -168,7 +168,7 @@ end
 
 
 function s080_shipyard.OnEndStrongReactionEvent()
-  Game.GetPlayer().INVENTORY:SetItemAmount("ITEM_METROIDNIZATION", 1, true)
+  --Game.GetPlayer().INVENTORY:SetItemAmount("ITEM_METROIDNIZATION", 1, true)
 end
 
 
@@ -435,6 +435,18 @@ function s080_shipyard.OnUsableFinishInteract(_ARG_0_)
   end
 end
 
+function s080_shipyard.OnUsablePrepareUse(actor)
+  Scenario.DisableGlobalTeleport(actor)
+end
+
+function s080_shipyard.OnUsableCancelUse(actor)
+  Scenario.ResetGlobalTeleport(actor)
+end
+
+function s080_shipyard.OnUsableUse(actor)
+  Scenario.SetTeleportalUsed(actor)
+end
+
 
 
 
