@@ -169,6 +169,7 @@ function RandomizerPowerup.IncreaseAmmo(resource)
 end
 
 function RandomizerPowerup.CheckArtifacts(resource)
+    if resource == nil then return end
     if Init.iNumRequiredArtifacts == 0 then return end
     if RandomizerPowerup.GetItemAmount("ITEM_METROIDNIZATION") > 0 then return end
     
@@ -183,7 +184,8 @@ function RandomizerPowerup.CheckArtifacts(resource)
 
     RandomizerPowerup.SetItemAmount("ITEM_METROIDNIZATION", 1)
 
-    Game.AddGUISF(0.1, "RandomizerPowerup.ShowArtifactMessage", "")
+    -- popup currently disabled since it causes a softlock
+    --Game.AddGUISF(0.1, "RandomizerPowerup.ShowArtifactMessage", "")
 end
 
 function RandomizerPowerup.ShowArtifactMessage()
